import * as React from "react";
export interface IDialogProps extends React.HTMLAttributes<HTMLElement> {
    /** (string) The title of the dialog */
    title?: string;
    /** (string) default: '#host' - The selector of the element you'd like to inject the dialog into */
    bodySelector?: string;
    /** (string) An additional class for the dialog layer, normally used for forcing higher z-index values  */
    layerClass?: string;
    /** (boolean) Setting this to true or false will open or close the dialog */
    isOpen: boolean;
    /** (number) The width of the dialog */
    width?: number;
    /** (number) The height of the dialog */
    height?: number;
    /** (()=> void) Event to fire when the dialog is closed */
    onClose: () => void;
    /** (()=> void) Event to fire when the x button is clicked. Use this to confirm (double dialogs) */
    onXClicked?: () => void;
    /** (boolean) Controls wether the dialog closes when the background overlay is clicked */
    closeOnBackgroundClick?: boolean;
}
export declare const Dialog: React.FC<IDialogProps>;
declare type DialogLayerCloseReason = "x-clicked" | "background" | "user";
export interface IDialogLayerPropsCore {
    title?: string;
    layerClass?: string;
    className?: string;
    width?: number;
    height?: number;
}
export interface IDialogLayerProps extends IDialogLayerPropsCore {
    onClose: (e: DialogLayerCloseReason) => void;
}
export declare const DialogLayer: React.FC<IDialogLayerProps>;
export interface IDialogPresenterProps {
    title?: string;
    className?: string;
    width?: number;
    height?: number;
    onClose: (e: React.MouseEvent<HTMLElement>) => void;
}
export declare const DialogPresenter: React.FC<IDialogPresenterProps>;
export interface IUseDialogProps {
    onClose: () => void;
}
export interface IUseDialogSettings extends IUsePortalSettings, IDialogLayerPropsCore {
    beforeDialogClose?: (reason: DialogLayerCloseReason) => Promise<boolean>;
}
export declare function useDialog(DialogLayerComponent: React.FC<IUseDialogProps>, settings?: IUseDialogSettings): {
    open: () => void;
    portal: React.ReactPortal;
};
export interface IUsePortalSettings {
    hostElement?: string;
    initiallyOpen?: boolean;
}
export declare function usePortal(PortalComponent: React.FC<IUseDialogProps>, settings?: IUsePortalSettings): {
    open: () => void;
    portal: React.ReactPortal;
};
export {};
