"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var arrayItems_1 = require("./arrayItems");
function useThrottle(value, limit, onValueChange) {
    var _a = React.useState(value), throttledValue = _a[0], setThrottledValue = _a[1];
    var lastRan = React.useRef(Date.now());
    React.useEffect(function () {
        var handler = setTimeout(function () {
            if (Date.now() - lastRan.current >= limit) {
                setThrottledValue(value);
                if (onValueChange) {
                    onValueChange(value);
                }
                lastRan.current = Date.now();
            }
        }, limit - (Date.now() - lastRan.current));
        return function () {
            clearTimeout(handler);
        };
    }, [value, limit]);
    return throttledValue;
}
exports.useThrottle = useThrottle;
function useRemoteOptions(remoteQuery) {
    var _a = React.useState([]), options = _a[0], setOptions = _a[1];
    var _b = React.useState(""), filter = _b[0], setFilter = _b[1];
    var onFilterChanged = React.useCallback(function (query) {
        remoteQuery(query).then(function (opts) { return setOptions(opts); }).catch(function (e) {
            // tslint:disable-next-line: no-console
            console.log("Unable to perform query");
        });
    }, [remoteQuery]);
    useThrottle(filter, 2000, onFilterChanged);
    return { options: options, filter: filter, setFilter: setFilter };
}
exports.useRemoteOptions = useRemoteOptions;
exports.AutoComplete = function (p) {
    if (p.multiSelect === "multiple") {
        return React.createElement(exports.AutoCompleteMultiInput, tslib_1.__assign({}, p));
    }
    return React.createElement(exports.AutoCompleteSingleInput, tslib_1.__assign({}, p));
};
exports.AutoCompleteSingleInput = function (p) {
    var filter = p.filter, onFilterChange = p.onFilterChange, options = p.options, value = p.value, onValueChange = p.onValueChange;
    return (React.createElement(React.Fragment, null,
        React.createElement("input", { value: filter, onChange: function (e) { return onFilterChange(e.currentTarget.value); } }),
        React.createElement("div", null, value && React.createElement("span", { onClick: function () { return onValueChange(undefined); } }, value.name)),
        React.createElement("ul", null, options.map(function (o) { return React.createElement("li", { key: o.id, onClick: function () { return onValueChange(value && value.id === o.id ? undefined : o); } }, o.name); }))));
};
exports.AutoCompleteMultiInput = function (p) {
    var filter = p.filter, onFilterChange = p.onFilterChange, options = p.options, value = p.value, onValueChange = p.onValueChange;
    return (React.createElement(React.Fragment, null,
        React.createElement("div", null,
            value && value.length > 0 && value.map(function (o, i) { return React.createElement("span", { onClick: function () { return onValueChange(arrayItems_1.arrayToggleItem(value, o)); }, key: o.id }, o.name); }),
            React.createElement("span", null,
                React.createElement("input", { value: filter, onChange: function (e) { return onFilterChange(e.currentTarget.value); } }))),
        React.createElement("ul", null, options.map(function (o) { return React.createElement("li", { key: o.id, onClick: function () { return onValueChange(arrayItems_1.arrayToggleItem(value, o)); } }, o.name); }))));
};
