"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var ReactDOM = require("react-dom");
var icon_1 = require("./../display/icon");
var BurgerMenuRef = function (props, ref) {
    var bodySelector = props.bodySelector, burgerButtonHidden = props.burgerButtonHidden, buttonIcon = props.buttonIcon, closeOnNavigate = props.closeOnNavigate, mode = props.mode, onMenuToggle = props.onMenuToggle, wrappingComponent = props.wrappingComponent, children = props.children;
    var appNode;
    var isOpen = React.useRef(false);
    React.useEffect(function () {
        var selector = bodySelector || "#host";
        appNode = document.querySelector(selector);
        if (!appNode) {
            // tslint:disable-next-line:no-console
            console.error("Cannot find document node of " + selector);
        }
    }, [bodySelector]);
    var closeMenu = React.useCallback(function () {
        var mode1 = mode || "push";
        if (mode1 === "push") {
            appNode.classList.remove("menu-open");
            appNode.classList.remove("menu-push");
        }
        else {
            appNode.classList.remove("menu-open");
            appNode.classList.remove("menu-slide");
        }
        isOpen.current = false;
        if (onMenuToggle) {
            onMenuToggle(burgerMenu());
        }
    }, [mode, onMenuToggle, appNode]);
    var openMenu = React.useCallback(function () {
        var mode1 = mode || "push";
        if (mode1 === "push") {
            appNode.classList.add("menu-open");
            appNode.classList.add("menu-push");
        }
        else {
            appNode.classList.add("menu-open");
            appNode.classList.add("menu-slide");
        }
        isOpen.current = true;
        if (onMenuToggle) {
            onMenuToggle(burgerMenu());
        }
    }, [mode, onMenuToggle, appNode]);
    var toggleMenu = React.useCallback(function () {
        if (!isOpen.current) {
            openMenu();
        }
        else {
            closeMenu();
        }
    }, [openMenu, closeMenu]);
    var closeNav = React.useCallback(function () {
        if (closeOnNavigate) {
            closeMenu();
        }
    }, [closeOnNavigate, closeMenu]);
    var renderMenu = React.useCallback(function () {
        return React.cloneElement(wrappingComponent || React.createElement(React.Fragment, null), null, React.createElement("div", null,
            mode === "slide" && React.createElement("div", { className: "burger-blocker", onClick: closeMenu }),
            React.createElement("nav", { className: "burger-menu" },
                React.createElement("ul", { className: "burger-menu-list" }, React.Children.map(children, function (c, index) {
                    return (React.createElement("li", { onClick: closeNav, key: "nav_item_" + index }, c));
                })))));
    }, [mode, children, closeMenu, wrappingComponent]);
    var burgerMenu = React.useCallback(function () {
        return {
            openMenu: openMenu,
            closeMenu: closeMenu,
            toggleMenu: toggleMenu,
            isOpen: isOpen.current,
        };
    }, [openMenu, closeMenu, toggleMenu, isOpen]);
    React.useImperativeHandle(ref, burgerMenu, [burgerMenu]);
    return (React.createElement(React.Fragment, null,
        React.createElement("button", { className: "burger-menu-button" + (burgerButtonHidden ? " hidden" : ""), onClick: toggleMenu }, buttonIcon && React.createElement(icon_1.Icon, { icon: buttonIcon })),
        ReactDOM.createPortal(renderMenu(), document.querySelector(bodySelector || "#host"))));
};
exports.BurgerMenu = React.forwardRef(BurgerMenuRef);
exports.BurgerMenuItem = function (props) {
    var title = props.title, icon = props.icon, onClick = props.onClick, style = props.style, delayActionMs = props.delayActionMs, active = props.active, attrs = tslib_1.__rest(props, ["title", "icon", "onClick", "style", "delayActionMs", "active"]);
    var handleClick = React.useCallback(function () {
        if (!onClick) {
            return;
        }
        if (delayActionMs) {
            window.setTimeout(function () {
                onClick();
            }, delayActionMs);
        }
        else {
            onClick();
        }
    }, [onClick, delayActionMs]);
    return (React.createElement("div", tslib_1.__assign({}, attrs, { role: "menuitem", className: "burger-menu-item" + (active ? " active" : ""), style: style, "aria-selected": active || false, onClick: handleClick }),
        icon && React.createElement(icon_1.Icon, { icon: icon }),
        title));
};
