"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var dates_1 = require("../utilities/dates");
var isoFormat = "YYYY-MM-DD";
function useCalendar(settings) {
    var format = React.useMemo(function () { return settings.format || isoFormat; }, [settings.format]);
    var startDay = React.useMemo(function () { return settings.beginOnDay || "Sun"; }, [settings.beginOnDay]);
    var displayFormat = React.useMemo(function () { return settings.displayFormat || isoFormat; }, [settings.displayFormat]);
    var seedDate = React.useMemo(function () { return dates_1.Dates.dateOrToday(settings.selectedDate || settings.seedDate, format); }, []);
    var minDate = React.useMemo(function () { return dates_1.Dates.dateOrNull(settings.minDate, format); }, [settings.minDate]);
    var maxDate = React.useMemo(function () { return dates_1.Dates.dateOrNull(settings.maxDate, format); }, [settings.maxDate]);
    var _a = React.useState(settings.selectedDate ? dates_1.Dates.dateOrEmpty(settings.selectedDate, format) : ""), date = _a[0], setCurrentDate = _a[1];
    var isSelectedDateValid = React.useMemo(function () {
        var mom = dates_1.Dates.dateOrNull(date, format);
        if (!mom) {
            return false;
        }
        return dates_1.Dates.fallsWithinRange(mom, minDate, maxDate);
    }, [date, minDate, maxDate, format]);
    var selectedDateDisplay = React.useMemo(function () {
        var mom = dates_1.Dates.dateOrNull(date, format);
        if (!mom) {
            return "";
        }
        return dates_1.Dates.format(mom, displayFormat);
    }, [date, isSelectedDateValid]);
    var today = dates_1.Dates.startOfToday().format(format);
    var _b = React.useState(buildWeeks(seedDate, format, startDay, displayFormat, today, date, minDate, maxDate)), state = _b[0], setState = _b[1];
    var nextMonth = React.useCallback(function () {
        if (!dates_1.Dates.fallsWithinRange(state.nextSeed, undefined, maxDate)) {
            return;
        }
        setState(buildWeeks(state.nextSeed, format, startDay, displayFormat, today, date, minDate, maxDate));
    }, [state.nextSeed, format, startDay, displayFormat, today, date, maxDate]);
    var previousMonth = React.useCallback(function () {
        if (!dates_1.Dates.fallsWithinRange(state.previousSeed, minDate, undefined)) {
            return;
        }
        setState(buildWeeks(state.previousSeed, format, startDay, displayFormat, today, date, minDate, maxDate));
    }, [state.previousSeed, format, startDay, displayFormat, today, date, minDate]);
    var nextYear = React.useCallback(function () {
        var nextSeed = state.seed.clone().add(1, "year");
        if (!dates_1.Dates.fallsWithinRange(nextSeed, undefined, maxDate)) {
            return;
        }
        setState(buildWeeks(nextSeed, format, startDay, displayFormat, today, date, minDate, maxDate));
    }, [state.seed, format, startDay, displayFormat, today, date, maxDate]);
    var previousYear = React.useCallback(function () {
        var previousSeed = state.seed.clone().add(-1, "year");
        if (!dates_1.Dates.fallsWithinRange(previousSeed, minDate, undefined)) {
            return;
        }
        setState(buildWeeks(previousSeed, format, startDay, displayFormat, today, date, minDate, maxDate));
    }, [state.seed, format, startDay, displayFormat, today, date, minDate]);
    var gotoDate = React.useCallback(function (newDate) {
        var mom = dates_1.Dates.dateOrToday(newDate, format);
        if (!dates_1.Dates.fallsWithinRange(mom, minDate, maxDate)) {
            return;
        }
        setState(buildWeeks(mom, format, startDay, displayFormat, today, date, minDate, maxDate));
    }, [format, startDay, displayFormat, today, date, minDate, maxDate]);
    var setDate = React.useCallback(function (newDate) {
        newDate = dates_1.Dates.dateOrEmpty(newDate, format);
        if (!newDate) {
            return;
        }
        var mom = dates_1.Dates.dateOrToday(newDate, format);
        if (!dates_1.Dates.fallsWithinRange(mom, minDate, maxDate)) {
            return;
        }
        setCurrentDate(newDate);
        setState(buildWeeks(mom, format, startDay, displayFormat, today, newDate, minDate, maxDate));
        if (settings.onDateChanged) {
            settings.onDateChanged(newDate);
        }
    }, [format, startDay, displayFormat, today, minDate, maxDate, settings.onDateChanged, setCurrentDate]);
    var clearSelectedDate = React.useCallback(function () {
        var newDate = "";
        setCurrentDate(newDate);
        setState(buildWeeks(state.seed, format, startDay, displayFormat, today, newDate, minDate, maxDate));
        if (settings.onDateChanged) {
            settings.onDateChanged(newDate);
        }
    }, [settings.onDateChanged, setCurrentDate, state.seed, format, startDay, displayFormat, today, minDate, maxDate]);
    return { month: state.month, nextMonth: nextMonth, nextYear: nextYear, previousMonth: previousMonth, previousYear: previousYear, selectedDateDisplay: selectedDateDisplay, selectedDate: date, selectDate: setDate, gotoDate: gotoDate, isSelectedDateValid: isSelectedDateValid, clearSelectedDate: clearSelectedDate };
}
exports.useCalendar = useCalendar;
function buildWeeks(seed, format, startDay, displayFormat, today, selectedDate, minDate, maxDate) {
    var start = dates_1.Dates.startOfMonth(seed);
    var monthNum = dates_1.Dates.getMonth(start);
    var monthShortName = dates_1.Dates.format(start, "MMM");
    var monthName = dates_1.Dates.format(start, "MMMM");
    var year = dates_1.Dates.getYear(start);
    var previousSeed = dates_1.Dates.addMonth(start, -1);
    var nextSeed = dates_1.Dates.addMonth(start, 1);
    while (!dates_1.Dates.isDayOfWeek(start, startDay)) {
        dates_1.Dates.addDay(start, -1);
    }
    var weeks = [];
    for (var weekNo = 0; weekNo < 6; weekNo++) {
        var week = { days: [] };
        weeks.push(week);
        for (var dayNo = 0; dayNo < 7; dayNo++) {
            var day = { date: dates_1.Dates.format(start, format), dayOfWeek: dates_1.Dates.getDayOfWeek(start), display: dates_1.Dates.format(start, displayFormat), dayNumber: dates_1.Dates.getDayNumber(start) };
            if (day.date === today) {
                day.isToday = true;
            }
            if (!dates_1.Dates.fallsWithinRange(start, minDate, maxDate)) {
                day.outOfRange = true;
            }
            if (day.date === selectedDate) {
                day.isCurrentDate = true;
            }
            if (dates_1.Dates.getMonth(start) === monthNum) {
                day.isCurrentMonth = true;
            }
            week.days.push(day);
            dates_1.Dates.addDay(start, 1);
        }
    }
    var month = { daysOfWeek: weeks[0].days.map(function (d) { return d.dayOfWeek; }), weeks: weeks, number: monthNum, shortName: monthShortName, name: monthName, year: year };
    return { month: month, seed: seed, previousSeed: previousSeed, nextSeed: nextSeed };
}
