"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var utils_1 = require("./utils");
var Dates;
(function (Dates) {
    function range1to(to) {
        return utils_1.Utils.range(1, to + 1).map(function (d) { return d; });
    }
    function getDaysArrayByMonth(month, year, minDate, maxDate) {
        var days = dayInMonth(month, year);
        if (minDate) {
            var min_1 = parseWireFormatDate(minDate);
            if (min_1.year() === year && min_1.month() === month) {
                days = utils_1.Utils.filter(days, function (d) { return d >= min_1.date(); });
            }
        }
        if (maxDate) {
            var max_1 = parseWireFormatDate(maxDate);
            if (max_1.year() === year && max_1.month() === month) {
                days = utils_1.Utils.filter(days, function (d) { return d <= max_1.date(); });
            }
        }
        return days;
    }
    Dates.getDaysArrayByMonth = getDaysArrayByMonth;
    function dayInMonth(month, year) {
        if (utils_1.Utils.isNullOrUndefined(month)) {
            return range1to(31);
        }
        if (utils_1.Utils.isNullOrUndefined(year)) {
            year = 2000;
        }
        var activeMoment = moment([year, month, 1]);
        if (!activeMoment.isValid()) {
            return range1to(31);
        }
        return range1to(activeMoment.daysInMonth());
    }
    function parseWireFormatDate(date) {
        return moment(date, "YYYY-MM-DD", true);
    }
    Dates.parseWireFormatDate = parseWireFormatDate;
    function datePartsChanged(newState, dateState) {
        return newState.day !== dateState.day || newState.month !== dateState.month || newState.year !== dateState.year;
    }
    Dates.datePartsChanged = datePartsChanged;
    function getDateParts(date, includeDate) {
        if (includeDate === void 0) { includeDate = false; }
        var d = parseWireFormatDate(date);
        var parts = { day: d.date(), month: d.month(), year: d.year() };
        if (includeDate) {
            parts.date = date;
        }
        return parts;
    }
    Dates.getDateParts = getDateParts;
    function toDateFormat(s) {
        if (!utils_1.Utils.isNullOrUndefined(s.day) && !utils_1.Utils.isNullOrUndefined(s.month) && !utils_1.Utils.isNullOrUndefined(s.year)) {
            var mom = moment([s.year, s.month, s.day]);
            if (mom.isValid()) {
                return mom.format("YYYY-MM-DD");
            }
        }
    }
    Dates.toDateFormat = toDateFormat;
    function getYearValues(minDate, maxDate, range) {
        if (range === void 0) { range = 110; }
        var start = minDate ? parseWireFormatDate(minDate).year() : moment().subtract(range, "years").year();
        var stop = maxDate ? parseWireFormatDate(maxDate).year() : moment().add(range, "years").year();
        return utils_1.Utils.range(start, stop + 1);
    }
    Dates.getYearValues = getYearValues;
    function getMonthValuesInRange(year, minDate, maxDate) {
        var months = getMonthValues();
        if (minDate) {
            var min_2 = parseWireFormatDate(minDate);
            if (min_2.year() === year) {
                months = utils_1.Utils.filter(months, function (d) { return d.value >= min_2.month(); });
            }
        }
        if (maxDate) {
            var max_2 = parseWireFormatDate(maxDate);
            if (max_2.year() === year) {
                months = utils_1.Utils.filter(months, function (d) { return d.value <= max_2.month(); });
            }
        }
        return months;
    }
    Dates.getMonthValuesInRange = getMonthValuesInRange;
    function getMonthValues() {
        return utils_1.Utils.range(0, 12).map(function (i) {
            var month = moment().month(i);
            return { value: i, label: month.format("MMMM") };
        });
    }
    Dates.getMonthValues = getMonthValues;
    function startOfToday() {
        return moment().startOf("day");
    }
    Dates.startOfToday = startOfToday;
    function fallsWithinRange(mom, minDate, maxDate) {
        if (minDate && mom.isBefore(minDate, "day")) {
            return false;
        }
        if (maxDate && mom.isAfter(maxDate, "day")) {
            return false;
        }
        return true;
    }
    Dates.fallsWithinRange = fallsWithinRange;
    function dateOrToday(date, formatString) {
        var mom = moment(date, formatString, true);
        if (!mom.isValid()) {
            return moment();
        }
        return mom;
    }
    Dates.dateOrToday = dateOrToday;
    function dateOrEmpty(date, formatString) {
        var mom = moment(date, formatString, true);
        if (!mom.isValid()) {
            return "";
        }
        return mom.format(formatString);
    }
    Dates.dateOrEmpty = dateOrEmpty;
    function dateOrNull(date, formatString) {
        var mom = moment(date, formatString, true);
        if (!mom.isValid()) {
            return;
        }
        return mom;
    }
    Dates.dateOrNull = dateOrNull;
    function startOfMonth(mom) {
        return mom.clone().startOf("month");
    }
    Dates.startOfMonth = startOfMonth;
    function getMonth(mom) {
        return mom.month();
    }
    Dates.getMonth = getMonth;
    function getDayNumber(mom) {
        return mom.date();
    }
    Dates.getDayNumber = getDayNumber;
    function getYear(mom) {
        return mom.year();
    }
    Dates.getYear = getYear;
    function format(mom, formatString) {
        return mom.format(formatString);
    }
    Dates.format = format;
    function addMonth(mom, increment) {
        return mom.clone().add(increment, "month");
    }
    Dates.addMonth = addMonth;
    function addDay(mom, increment) {
        return mom.add(increment, "day");
    }
    Dates.addDay = addDay;
    function getDayOfWeek(mom) {
        return mom.format("ddd");
    }
    Dates.getDayOfWeek = getDayOfWeek;
    function isDayOfWeek(mom, dayOfWeek) {
        return getDayOfWeek(mom) === dayOfWeek;
    }
    Dates.isDayOfWeek = isDayOfWeek;
})(Dates = exports.Dates || (exports.Dates = {}));
